@@ -8,12 +8,12 @@ import site
 def read_pyspark_model():
     # newv = "nltkTransformer-0.0.12/nlp/"
     # return mlflow.spark.load_model(site.getsitepackages()[0] + "/nlp/")
-    return mlflow.spark.load_model("/opt/anaconda3/envs/azurefunc/lib/python3.7/site-packages" + "/nlp")
+    return mlflow.spark.load_model("/opt/anaconda3/envs/azurefunc/lib/python3.7/site-packages/nlp" + "")
 
 def read_pyfunc_model():
     # newv = "nltkTransformer-0.0.12/nlp/"
     # return mlflow.pyfunc.load_model(site.getsitepackages()[0] + "/nlp/")
-    return mlflow.pyfunc.load_model("/opt/anaconda3/envs/azurefunc/lib/python3.7/site-packages" + "/nlp")
+    return mlflow.pyfunc.load_model("/opt/anaconda3/envs/azurefunc/lib/python3.7/site-packages/nlp" + "")
 #
 # print(read_model())
 # # from pyspark.sql import SparkSession
